"""Submodule relative to cell lines utilities."""
from typing import List


def get_window_sizes() -> List[int]:
    """Return list of the available window sizes."""
    return [
        64, 128, 256, 512, 1024
    ]



"""Generic utilities used in the package."""
from .normalize_epigenomic_data import normalize_epigenomic_data
from .cell_lines import get_cell_lines
from .window_sizes import get_window_sizes
from .available_metrics import get_available_metrics

__all__ = [
    "normalize_epigenomic_data",
    "get_cell_lines",
    "get_window_sizes",
    "get_available_metrics"
]
